@@ -5,34 +5,22 @@ from os import listdir, makedirs, chdir, rename
 from os.path import isdir, islink, join, exists
 from pickle import load as pload, dump as pdump
 from typing import Optional
-from yaml import safe_load_all as yload, dump as ydump
-from pandas.core.frame import DataFrame
 from regex import compile
-from pandas import read_csv, read_table
 from time import time
 from sys import path as sys_path
 from collections import OrderedDict
 from os import makedirs
-from zipfile import ZipFile
-from gzip import GzipFile
 from shutil import copyfileobj
-from tarfile import open as open_tar
-from bz2 import open as open_bz2
-from rarfile import RarFile
-from py7zr import SevenZipFile
-from lzma import open as open_lzma, decompress as lzdecompress
 
 REGEX_FIND_EPISODE = compile(r'(?P<SEASON>\d+)\s*[x\-]\s*(?P<EPISODE>\d+)|S\s*(?P<SEASON>\d+)\s*E\s*(?P<EPISODE>\d+)|(?P<EPISODE>\d+)').search
 
-def cwd():
+def cwd() -> None:
 	''' Change the base of relative paths to the directory of the main script. '''
 	chdir(sys_path[0])
 
-
 _load_formats = 'bytes', 'csv', 'json', 'jsonl', 'pickle', 'string', 'table', 'yaml'
 def load(path: str, format: str = 'auto', encoding: str = 'utf-8', inner_args: list = None, inner_kwargs: dict = None) -> object:
 	''' Load a file in a given format. '''
-	format = detect_format(path, format)
 	format = detect_format(path, format, accept=_load_formats, default='string')
 	args = [] if inner_args is None else inner_args
 	kwargs = {} if inner_kwargs is None else inner_kwargs
@@ -47,12 +35,15 @@ def load(path: str, format: str = 'auto', encoding: str = 'utf-8', inner_args: l
 	elif format == 'jsonl':
 		res = [jload(line, *args, **kwargs) for line in fp]
 	elif format == 'csv':
+		from pandas import read_csv
 		res = read_csv(fp, *args, **kwargs)
 	elif format == 'table':
+		from pandas import read_table
 		res = read_table(fp, *args, **kwargs)
 	elif format == 'pickle':
 		res = pload(fp, *args, **kwargs)
 	elif format == 'yaml':
+		from yaml import safe_load_all as yload
 		res = list(yload(fp, *args, **kwargs))
 		res = res[0] if len(res) == 1 else res
 	fp.close()
@@ -83,39 +74,50 @@ def save(path: str, content: object, format: str = 'auto', encoding: str = 'utf-
 		if 'protocol' not in kwargs: kwargs['protocol'] = 4
 		pdump(content, fp, *args, **kwargs)
 	elif format == 'csv':
+		from pandas import DataFrame
 		if 'index' not in kwargs: kwargs['index'] = False
 		DataFrame(content).to_csv(path, *args, **kwargs)
 	elif format == 'table':
+		from pandas import DataFrame
 		if 'index' not in kwargs: kwargs['index'] = False
 		DataFrame(content).to_excel(path, *args, **kwargs)
 	elif format == 'yaml':
+		from yaml import dump as ydump
 		ydump(content, fp, *args, **kwargs)
 	if fp is not None:
 		fp.close()
 
 _decompress_formats = 'tar', 'zip', 'gzip', 'bzip2', 'rar', '7zip', 'lzma'
-def decompress(path: str, output: str, format: str = 'auto'):
+def decompress(path: str, output: str, format: str = 'auto') -> None:
+	''' Decompress the given file to the output directory regardless of its format. '''
 	format = detect_format(path, format, accept=_decompress_formats)
 	makedirs(output, exist_ok=True)
 	if format == 'zip':
+		from zipfile import ZipFile
 		with ZipFile(path, 'r') as zipped:
 			zipped.extractall(output)
 	elif format == 'gzip':
+		from gzip import GzipFile
 		with GzipFile(path, 'r') as zipped, open(output, 'wb') as file_dest:
 			copyfileobj(zipped, file_dest)
 	elif format == 'rar':
+		from rarfile import RarFile
 		with RarFile(path, 'r') as zipped:
 			zipped.extractall(output)
 	elif format == 'bzip2':
+		from bz2 import open as open_bz2
 		with open_bz2(path, 'r') as zipped, open(output, 'wb') as file_dest:
 			copyfileobj(zipped, file_dest)
 	elif format == 'tar':
+		from tarfile import open as open_tar
 		with open_tar(path) as zipped:
 			zipped.extractall(output)
 	elif format == '7zip':
+		from py7zr import SevenZipFile
 		with SevenZipFile(path, 'r') as zipped:
 			zipped.extractall(output)
 	elif format == 'lzma':
+		from lzma import open as open_lzma, decompress as lzdecompress
 		with open_lzma(path, 'r') as zipped, open(output, 'wb') as file_dest:
 			copyfileobj(lzdecompress(zipped), file_dest)
 
@@ -137,6 +139,7 @@ _detect_format_exts = OrderedDict((
 	('lzma', ('lzip', 'lz')),
 ))
 def detect_format(path: str, format: str, accept: list = None, default: str = None) -> Optional[str]:
+	''' Detects the format of a file from its path. '''
 	if format == 'auto':
 		name = path.lower()
 		for ext_format, exts in _detect_format_exts.items():
@@ -157,7 +160,7 @@ def disk_cache(func=None, *, seconds: float = None, directory: str = '.cached/',
 	next call loads the cached result from the disk. The cached files are used indefinitely unless the
 	`seconds` lifespan is defined. The cached files are stored at `.cached` unless otherwise
 	specificed with the `directory` argument. The cache file identifier is generated from the
-	method name its arguments unless otherwise specified with the `identifier` argument. '''
+	method name plus its arguments, unless otherwise specified with the `identifier` argument. '''
 	def decorator(func):
 		def wrapper(*args, **kwargs):
 			makedirs(directory, exist_ok=True)
@@ -191,7 +194,7 @@ def disk_cache(func=None, *, seconds: float = None, directory: str = '.cached/',
 	else:
 		return decorator
 
-def size(file):
+def size(file) -> int:
 	''' A way to see the size of a file without loading it to memory. '''
 	if file.content_length:
 		return file.content_length
@@ -229,7 +232,9 @@ _find_hidden_compressed_signatures = {
 	# 'tar': b'\x1f\x9d',
 	# 'bz2': b'\x42\x5a\x68',
 }
-def find_hidden_compressed(path):
+def find_hidden_compressed(path: str) -> list:
+	''' Recursively examines the signature of the files in a directory while looking for a
+	compressed file. '''
 	with open(path, 'rb') as fp:
 		data = fp.read()
 		signatures = []
@@ -238,9 +243,9 @@ def find_hidden_compressed(path):
 				signatures.append(ftype)
 		return signatures
 
-def tvshow_rename(path):
+def tvshow_rename(path: str) -> None:
 	''' Rename every TV show of a folder.
-	E.g. Inception_Season_4_Episode_02_DivX-Total.mkv would be 04x02.mkv. '''
+	I.e. Inception_Season_4_Episode_02_DivX-Total.mkv would be 04x02.mkv. '''
 	for file in listdir(path):
 		name, ext = file.rsplit('.', 1)
 		match = REGEX_FIND_EPISODE(name.replace('_', ' '))
@@ -252,7 +257,9 @@ def tvshow_rename(path):
 			rename(file, name)
 
 _directory_compare_ignored = ('.class', '.metadata', '.recommenders', '.pyc', '.git', '.svn', '.cached', '__pycache__')
-def directory_compare(old, new, kind='dir', ignored=_directory_compare_ignored):
+def directory_compare(old: str, new: str, kind: str = 'dir', ignored: list = _directory_compare_ignored) -> None:
+	''' Compares the files in two directories (old and new) to detect files that have been created,
+	deleted, changed or updated, ignoring the specified files. '''
 	def children(path):
 		res = {}
 		for child in listdir(path):
